﻿using System;
using System.Drawing;

using MindFusion.Diagramming;

using SolidBrush = MindFusion.Drawing.SolidBrush;
using ImageAlign = MindFusion.Drawing.ImageAlign;


namespace LayeredLayoutSample
{
	public partial class _Default : System.Web.UI.Page
	{
		protected void Page_Load(object sender, EventArgs e)
		{
			if (!IsPostBack)
			{
				Diagram diagram = diagramView.Diagram;
				diagram.MeasureUnit = MeasureUnit.Pixel;
				diagram.Bounds = new RectangleF(0, 0, 600, 400);
				diagram.BackBrush = new SolidBrush(Color.White);
				diagram.SelectAfterCreate = false;

				diagram.DefaultShape = Shapes.Rectangle;
				diagram.RoundedLinks = true;
				diagram.RoundedLinksRadius = 12;

				diagram.LinkHeadShape = ArrowHeads.BowArrow;
				diagram.LinkHeadShapeSize = 15;

				diagram.DiagramStyle.FontFamily = "Microsoft Sans Serif";
				diagram.DiagramStyle.FontSize = 10;
				diagram.DiagramStyle.FontUnit = GraphicsUnit.Point;
			}
		}

		protected void btnRandom_Click(object sender, EventArgs e)
		{
			Diagram diagram = diagramView.Diagram;

			// choose random fill color for the new box
			Random rnd = new Random();
			diagram.ShapeNodeStyle.Brush = new SolidBrush(Color.FromArgb(
				rnd.Next(0, 255), rnd.Next(0, 255), rnd.Next(0, 255)));

			// create the box
			ShapeNode node = diagram.Factory.CreateShapeNode(
				rnd.Next(10, 520), rnd.Next(10, 340), 40, 50);
			node.Text = diagram.Nodes.Count.ToString();
			node.TextFormat.LineAlignment = StringAlignment.Far;
			node.HyperLink = "http://mindfusion.eu";
			//node.HyperLink = "javascript: void alert('clicked')";

			// setup icon
			node.Transparent = true;
			node.Image = new Bitmap(
				Server.MapPath("Images\\" + rnd.Next(4).ToString() + ".png"));
			node.ImageAlign = ImageAlign.TopCenter;

			if (diagram.Nodes.Count > 1)
			{
				DiagramLink link;

				// link the box with a previous one
				if (diagram.Nodes.Count % 2 == 0)
					link = diagram.Factory.CreateDiagramLink(
						diagram.Nodes[rnd.Next(0, diagram.Nodes.Count - 2)],
						diagram.Nodes[diagram.Nodes.Count - 1]);
				else
					link = diagram.Factory.CreateDiagramLink(
						diagram.Nodes[diagram.Nodes.Count - 1],
						diagram.Nodes[rnd.Next(0, diagram.Nodes.Count - 2)]);
				link.HyperLink = "http://www.mindfusion.eu/Forum/YaBB.pl";

				if (diagram.Nodes.Count > 5)
				{
					// link the box with a previous one
					if (diagram.Nodes.Count % 2 == 1)
						link = diagram.Factory.CreateDiagramLink(
							diagram.Nodes[rnd.Next(0, diagram.Nodes.Count - 2)],
							diagram.Nodes[diagram.Nodes.Count - 1]);
					else
						link = diagram.Factory.CreateDiagramLink(
							diagram.Nodes[diagram.Nodes.Count - 1],
							diagram.Nodes[rnd.Next(0, diagram.Nodes.Count - 2)]);
					link.HyperLink = "http://www.mindfusion.eu/Forum/YaBB.pl";
				}
			}

			diagram.ResizeToFitItems(10);
		}

		protected void btnClear_Click(object sender, EventArgs e)
		{
			diagramView.Diagram.ClearAll();
		}

		protected void btnLayout_Click(object sender, EventArgs e)
		{
			Diagram diagram = diagramView.Diagram;

			// LayeredLayout is available only in NetDiagram Pro edition
			MindFusion.Diagramming.Layout.LayeredLayout ll =
				new MindFusion.Diagramming.Layout.LayeredLayout();
			ll.LayerDistance = 50;
			ll.NodeDistance = 60;
			ll.SplitLayers = true;
			ll.Orientation = MindFusion.Diagramming.Layout.Orientation.Horizontal;
			ll.StraightenLongLinks = true;
			ll.Arrange(diagram);

			diagram.ResizeToFitItems(10);
		}
	}
}